@@ -4,15 +4,15 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.049 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common 2.052 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base 2.049 ;
-use IO::Uncompress::Adapter::UnLzma 2.049 ;
+use IO::Uncompress::Base 2.052 ;
+use IO::Uncompress::Adapter::UnLzma 2.052 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzmaError);
 
-$VERSION = '2.049';
+$VERSION = '2.052';
 $UnLzmaError = '';
 
 @ISA    = qw( Exporter IO::Uncompress::Base );
@@ -40,7 +40,7 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common 2.049 qw(:Parse);
+    use IO::Compress::Base::Common 2.052 qw(:Parse);
     
     return (
         #'Verbosity'     => [1, 1, Parse_boolean,   0],
@@ -581,7 +581,7 @@ The string '-' can be used as an alias for standard input.
 =item A scalar reference 
 
 If C<$input> is a scalar reference, the compressed data will be read from
-C<$$output>.
+C<$$input>.
 
 =back
 
